![GitHub all releases](https://img.shields.io/github/downloads/casadi/casadi/total?label=github%20downloads)
![PyPI - Downloads](https://img.shields.io/pypi/dm/casadi?label=pypi%20downloads)


Learn all about CasADi at the [homepage](http://casadi.org) or jump to [install instructions](http://install.casadi.org)...
